##  Minimum Required Permissions
A custom profile can be created to perform the Apptio API upload with the minimum permissions required. If desired, create a custom role and assign it the following permissions:
  * AccessDev
  * UploadData


YesNo
Send
